@@ -293,7 +293,7 @@ for AperName in aperture_name_list:
                 setattr(aperture, 'XIdlVert{:d}'.format(j + 1), corners_Idl_x[j])
                 setattr(aperture, 'YIdlVert{:d}'.format(j + 1), corners_Idl_y[j])
 
-        elif dependency_type == 'grism_f444w':
+        elif dependency_type == 'grism_ts_sw':
             aperture._parent_apertures = [s.strip() for s in parent_apertures.split(';')]
 
             # the SCA on which this aperture is located
@@ -301,14 +301,14 @@ for AperName in aperture_name_list:
             for attribute in 'DetSciYAngle Sci2IdlDeg DetSciParity VIdlParity'.split():
                 setattr(aperture, attribute, getattr(master_aperture, attribute))
 
-            # the aperture on A5 whose V2Ref, V3Ref should be matched
-            a5_aperture = aperture_dict[aperture._parent_apertures[1]]
+            # the aperture on the LW channel whose V2Ref, V3Ref should be matched
+            LW_aperture = aperture_dict[aperture._parent_apertures[1]]
 
             # compute V2Ref, V3Ref, distortion from XDetRef and YDetRef of aperture, based on the parent_aperture
             aperture = tools.set_reference_point_and_distortion(instrument, aperture, master_aperture)
 
-            # modify aperture so that V2Ref, V3Ref match the a5_aperture
-            aperture = tools.match_v2v3(copy.deepcopy(a5_aperture), copy.deepcopy(aperture),
+            # modify aperture so that V2Ref, V3Ref match the LW_aperture
+            aperture = tools.match_v2v3(copy.deepcopy(LW_aperture), copy.deepcopy(aperture),
                                         verbose=False, match_v2_only=True)
 
             aperture.complement()
@@ -388,14 +388,21 @@ if emulate_delivery:
 
         create_jira_plots = True
         if create_jira_plots:
-            # # make figures for JWSTSIAF-160 Jira ticket
-            selected_aperture_names = [['NRCA2_MASK210R', 'NRCA2_FULL_MASK210R',
-                                        'NRCA5_MASK335R','NRCA5_FULL_MASK335R',
-                                        'NRCA5_MASK430R','NRCA5_FULL_MASK430R',
-                                        'NRCA2_FULL_WEDGE_RND','NRCA4_FULL_WEDGE_BAR',
-                                        'NRCA5_FULL_WEDGE_RND','NRCA5_FULL_WEDGE_BAR'
-                                       ]
-                                       ]
+            # # make figures for JWSTSIAF-184 Jira ticket
+            selected_aperture_names = [['NRCA1_FULL_WEDGE_RND','NRCA2_FULL_WEDGE_RND','NRCA3_FULL_WEDGE_RND','NRCA4_FULL_WEDGE_RND','NRCA2_MASK210R'],
+                                       ['NRCA1_FULL_WEDGE_BAR','NRCA2_FULL_WEDGE_BAR','NRCA3_FULL_WEDGE_BAR','NRCA4_FULL_WEDGE_BAR','NRCA4_MASKSWB'],
+                                       ['NRCA5_FULL_WEDGE_RND','NRCA5_MASK335R','NRCA5_MASK430R'],
+                                       ['NRCA5_FULL_WEDGE_BAR','NRCA5_MASKLWB'],
+                                       ['NRCA2_MASK210R','NRCA2_TAMASK210R','NRCA2_FSTAMASK210R'],
+                                       ['NRCA4_MASKSWB','NRCA4_MASKSWB_F182M','NRCA4_MASKSWB_F187N','NRCA4_MASKSWB_F210M','NRCA4_MASKSWB_F212N','NRCA4_MASKSWB_F200W','NRCA4_MASKSWB_NARROW',
+                                        'NRCA4_TAMASKSWB','NRCA4_TAMASKSWBS','NRCA4_FSTAMASKSWB'  ],
+                                       ['NRCA5_MASK335R','NRCA5_TAMASK335R','NRCA5_FSTAMASK335R'],
+                                       ['NRCA5_MASK430R','NRCA5_TAMASK430R','NRCA5_FSTAMASK430R'],
+                                       ['NRCA5_MASKLWB','NRCA5_MASKLWB_F250M','NRCA5_MASKLWB_F300M','NRCA5_MASKLWB_F277W','NRCA5_MASKLWB_F335M','NRCA5_MASKLWB_F360M','NRCA5_MASKLWB_F356W',
+                                        'NRCA5_MASKLWB_F410M','NRCA5_MASKLWB_F430M','NRCA5_MASKLWB_F460M','NRCA5_MASKLWB_F480M','NRCA5_MASKLWB_F444W','NRCA5_MASKLWB_NARROW',
+                                        'NRCA5_TAMASKLWB','NRCA5_TAMASKLWBL','NRCA5_FSTAMASKLWB']
+                                        ]
+                                                             
 
             for selected_aperture_name in selected_aperture_names:
                 compare.compare_inspection_figures(pre_delivery_siaf, reference_siaf_input=ref_siaf,
@@ -414,7 +421,7 @@ if emulate_delivery:
     # run some tests on the new SIAF
     from pysiaf.tests import test_aperture
     print('\nRunning aperture_transforms test for pre_delivery_siaf')
-    test_aperture.test_jwst_aperture_transforms([pre_delivery_siaf], verbose=False, threshold=0.1)
+    test_aperture.test_jwst_aperture_transforms([pre_delivery_siaf], verbose=False, threshold=1.)
     print('\nRunning aperture_vertices test for pre_delivery_siaf')
     test_aperture.test_jwst_aperture_vertices([pre_delivery_siaf])
 
